translate.convert.po2rc

Package translate :: Package convert :: Module po2rc |
[hide private]
[frames] | no frames]

# Module po2rc

source code

Convert Gettext PO localization files back to Windows Resource (.rc) files

See: http://translate.sourceforge.net/wiki/toolkit/po2rc for examples and usage instructions.

Classes | [hide private]
| rerc

Functions | [hide private]
convertrc(inputfile, outputfile, templatefile, includefuzzy=False, charset=None, lang=None, sublang=None) | source code
main(argv=None) | source code

Imports: po, rc